@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.13 2003/03/14 10:32:36 roland Exp $
+ *	$Id: syscallent.h,v 1.15 2003/07/17 09:07:41 roland Exp $
  */
 
 /*
@@ -1133,12 +1133,12 @@
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"	}, /* 1227 */
 	{ 2,	0,	sys_removexattr,	"fremovexattr"	}, /* 1228 */
 	{ 2,	TS,	sys_kill,		"tkill"		}, /* 1229 */
-	{ 4,	0,	sys_futex,		"futex"		}, /* 1230 */
+	{ 5,	0,	sys_futex,		"futex"		}, /* 1230 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"},/* 1231 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"},/* 1232 */
 	{ 1,	0,	printargs,		"set_tid_address"}, /* 1233 */
 	{ 8,	0,	printargs,		"SYS_1234"	}, /* 1234 */
-	{ 8,	0,	printargs,		"SYS_1235"	}, /* 1235 */
+	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 1235 */
 	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 1236 */
 	{ 4,	0,	printargs,		"lookup_dcookie"}, /* 1237 */
 	{ 2,	0,	printargs,		"io_setup"	}, /* 1238 */
