@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.12 2003/05/23 00:29:00 roland Exp $
+ *	$Id: syscallent.h,v 1.16 2004/02/20 02:25:18 roland Exp $
  */
 
 	{ 5,	0,	printargs,		"SYS_0"			}, /* 0 */
@@ -250,88 +250,132 @@
 	{ 2,	TF,	sys_removexattr,	"removexattr"		}, /* 218 */
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"		}, /* 219 */
 	{ 2,	0,	sys_fremovexattr,	"fremovexattr"		}, /* 220 */
-	{ 4,	0,	sys_futex,		"futex"			}, /* 221 */
+	{ 5,	0,	sys_futex,		"futex"			}, /* 221 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"	}, /* 222 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"	}, /* 223 */
 	{ 5,	0,	printargs,		"SYS_224"		}, /* 224 */
-	{ 5,	0,	printargs,		"SYS_225"		}, /* 225 */
+	{ 5,	0,	printargs,		"tux"			}, /* 225 */
 	{ 4,	TF,	sys_sendfile64,		"sendfile64"		}, /* 226 */
 	{ 2,	0,	printargs,		"io_setup"		}, /* 227 */
 	{ 1,	0,	printargs,		"io_destroy"		}, /* 228 */
 	{ 5,	0,	printargs,		"io_getevents"		}, /* 229 */
 	{ 3,	0,	printargs,		"io_submit"		}, /* 230 */
 	{ 3,	0,	printargs,		"io_cancel"		}, /* 231 */
-	{ 5,	0,	printargs,		"SYS_232"		}, /* 232 */
-	{ 5,	0,	printargs,		"SYS_233"		}, /* 233 */
+	{ 1,	0,	printargs,		"set_tid_address"	}, /* 232 */
+	{ 6,	0,	printargs,		"fadvise64"		}, /* 233 */
 	{ 1,	TP,	sys_exit,		"exit_group"		}, /* 234 */
 	{ 4,	0,	printargs,		"lookup_dcookie"	}, /* 235 */
 	{ 1,	0,	printargs,		"epoll_create"		}, /* 236 */
 	{ 4,	0,	printargs,		"epoll_ctl"		}, /* 237 */
 	{ 4,	0,	printargs,		"epoll_wait"		}, /* 238 */
 	{ 5,	0,	sys_remap_file_pages,	"remap_file_pages"	}, /* 239 */
-	{ 1,	0,	printargs,		"set_tid_address"	}, /* 240 */
-	{ 5,	0,	printargs,		"SYS_241"		}, /* 241 */
-	{ 5,	0,	printargs,		"SYS_242"		}, /* 242 */
-	{ 5,	0,	printargs,		"SYS_243"		}, /* 243 */
-	{ 5,	0,	printargs,		"SYS_244"		}, /* 244 */
-	{ 5,	0,	printargs,		"SYS_245"		}, /* 245 */
-	{ 5,	0,	printargs,		"SYS_246"		}, /* 246 */
-	{ 5,	0,	printargs,		"SYS_247"		}, /* 247 */
-	{ 5,	0,	printargs,		"SYS_248"		}, /* 248 */
-	{ 5,	0,	printargs,		"SYS_249"		}, /* 249 */
-	{ 5,	0,	printargs,		"SYS_250"		}, /* 250 */
-	{ 5,	0,	printargs,		"SYS_251"		}, /* 251 */
-	{ 5,	0,	printargs,		"SYS_252"		}, /* 252 */
-	{ 5,	0,	printargs,		"SYS_253"		}, /* 253 */
-	{ 5,	0,	printargs,		"SYS_254"		}, /* 254 */
-	{ 5,	0,	printargs,		"SYS_255"		}, /* 255 */
+	{ 3,	0,	sys_timer_create,	"timer_create"		}, /* 240 */
+	{ 4,	0,	sys_timer_settime,	"timer_settime"		}, /* 241 */
+	{ 2,	0,	sys_timer_gettime,	"timer_gettime"		}, /* 242 */
+	{ 1,	0,	sys_timer_getoverrun,	"timer_getoverrun"	}, /* 243 */
+	{ 1,	0,	sys_timer_delete,	"timer_delete"		}, /* 244 */
+	{ 2,	0,	sys_clock_settime,	"clock_settime"		}, /* 245 */
+	{ 2,	0,	sys_clock_gettime,	"clock_gettime"		}, /* 246 */
+	{ 2,	0,	sys_clock_getres,	"clock_getres"		}, /* 247 */
+	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"	}, /* 248 */
+	{ 2,	0,	printargs,		"swapcontext"		}, /* 249 */
+	{ 3,	TS,	sys_tgkill,		"tgkill"		}, /* 250 */
+	{ 2,	TF,	sys_utimes,		"utimes"		}, /* 251 */
+	{ 3,	TF,	sys_statfs64,		"statfs64"		}, /* 252 */
+	{ 3,	0,	sys_fstatfs64,		"fstatfs64"		}, /* 253 */
+	{ 6,	0,	printargs,		"fadvise64_64"		}, /* 254 */
+	{ 1,	0,	printargs,		"rtas"			}, /* 255 */
+	{ 5,	0,	printargs,		"SYS_256"		}, /* 256 */
+	{ 5,	0,	printargs,		"SYS_257"		}, /* 257 */
+	{ 5,	0,	printargs,		"SYS_258"		}, /* 258 */
+	{ 5,	0,	printargs,		"SYS_259"		}, /* 259 */
+	{ 5,	0,	printargs,		"SYS_260"		}, /* 260 */
+	{ 5,	0,	printargs,		"SYS_261"		}, /* 261 */
+	{ 5,	0,	printargs,		"SYS_262"		}, /* 262 */
+	{ 5,	0,	printargs,		"SYS_263"		}, /* 263 */
+	{ 5,	0,	printargs,		"SYS_264"		}, /* 264 */
+	{ 5,	0,	printargs,		"SYS_265"		}, /* 265 */
+	{ 5,	0,	printargs,		"SYS_266"		}, /* 266 */
+	{ 5,	0,	printargs,		"SYS_267"		}, /* 267 */
+	{ 5,	0,	printargs,		"SYS_268"		}, /* 268 */
+	{ 5,	0,	printargs,		"SYS_269"		}, /* 269 */
+	{ 5,	0,	printargs,		"SYS_270"		}, /* 270 */
+	{ 5,	0,	printargs,		"SYS_271"		}, /* 271 */
+	{ 5,	0,	printargs,		"SYS_272"		}, /* 272 */
+	{ 5,	0,	printargs,		"SYS_273"		}, /* 273 */
+	{ 5,	0,	printargs,		"SYS_274"		}, /* 274 */
+	{ 5,	0,	printargs,		"SYS_275"		}, /* 275 */
+	{ 5,	0,	printargs,		"SYS_276"		}, /* 276 */
+	{ 5,	0,	printargs,		"SYS_277"		}, /* 277 */
+	{ 5,	0,	printargs,		"SYS_278"		}, /* 278 */
+	{ 5,	0,	printargs,		"SYS_279"		}, /* 279 */
+	{ 5,	0,	printargs,		"SYS_280"		}, /* 280 */
+	{ 5,	0,	printargs,		"SYS_281"		}, /* 281 */
+	{ 5,	0,	printargs,		"SYS_282"		}, /* 282 */
+	{ 5,	0,	printargs,		"SYS_283"		}, /* 283 */
+	{ 5,	0,	printargs,		"SYS_284"		}, /* 284 */
+	{ 5,	0,	printargs,		"SYS_285"		}, /* 285 */
+	{ 5,	0,	printargs,		"SYS_286"		}, /* 286 */
+	{ 5,	0,	printargs,		"SYS_287"		}, /* 287 */
+	{ 5,	0,	printargs,		"SYS_288"		}, /* 288 */
+	{ 5,	0,	printargs,		"SYS_289"		}, /* 289 */
+	{ 5,	0,	printargs,		"SYS_290"		}, /* 290 */
+	{ 5,	0,	printargs,		"SYS_291"		}, /* 291 */
+	{ 5,	0,	printargs,		"SYS_292"		}, /* 292 */
+	{ 5,	0,	printargs,		"SYS_293"		}, /* 293 */
+	{ 5,	0,	printargs,		"SYS_294"		}, /* 294 */
+	{ 5,	0,	printargs,		"SYS_295"		}, /* 295 */
+	{ 5,	0,	printargs,		"SYS_296"		}, /* 296 */
+	{ 5,	0,	printargs,		"SYS_297"		}, /* 297 */
+	{ 5,	0,	printargs,		"SYS_298"		}, /* 298 */
+	{ 5,	0,	printargs,		"SYS_299"		}, /* 299 */
 
-	{ 8,	0,	printargs,		"socket_subcall"}, /* 256 */
-	{ 3,	TN,	sys_socket,		"socket"	}, /* 257 */
-	{ 3,	TN,	sys_bind,		"bind"		}, /* 258 */
-	{ 3,	TN,	sys_connect,		"connect"	}, /* 259 */
-	{ 2,	TN,	sys_listen,		"listen"	}, /* 260  */
-	{ 3,	TN,	sys_accept,		"accept"	}, /* 261 */
-	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 262 */
-	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 263 */
-	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 264 */
-	{ 4,	TN,	sys_send,		"send"		}, /* 265 */
-	{ 4,	TN,	sys_recv,		"recv"		}, /* 266 */
-	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 267 */
-	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 268 */
-	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 269 */
-	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 270 */
-	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 271 */
-	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 272 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 273 */
+	{ 8,	0,	printargs,		"socket_subcall"}, /* 300 */
+	{ 3,	TN,	sys_socket,		"socket"	}, /* 301 */
+	{ 3,	TN,	sys_bind,		"bind"		}, /* 302 */
+	{ 3,	TN,	sys_connect,		"connect"	}, /* 303 */
+	{ 2,	TN,	sys_listen,		"listen"	}, /* 304 */
+	{ 3,	TN,	sys_accept,		"accept"	}, /* 305 */
+	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 306 */
+	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 307 */
+	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 308 */
+	{ 4,	TN,	sys_send,		"send"		}, /* 309 */
+	{ 4,	TN,	sys_recv,		"recv"		}, /* 310 */
+	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 311 */
+	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 312 */
+	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 313 */
+	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 314 */
+	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 315 */
+	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 316 */
+	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 317 */
 
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 274 */
-	{ 4,	TI,	printargs,		"semop"		}, /* 275 */
-	{ 4,	TI,	sys_semget,		"semget"	}, /* 276 */
-	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 277 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 278 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 279 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 280 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 281 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 282 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 283 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 284 */
-	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 285 */
-	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 286 */
-	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 287 */
-	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 288 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 289 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 290 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 291 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 292 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 293 */
-	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 294 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 295 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 296 */
-	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 297 */
-	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 298 */
-	{ 5,	0,	printargs,		"SYS_299"	}, /* 299 */
-	{ 5,	0,	printargs,		"SYS_300"	}, /* 300 */
-	{ 5,	0,	printargs,		"SYS_301"	}, /* 301 */
-	{ 5,	0,	printargs,		"SYS_302"	}, /* 302 */
-	{ 5,	0,	printargs,		"SYS_303"	}, /* 303 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 318 */
+	{ 4,	TI,	printargs,		"semop"		}, /* 319 */
+	{ 4,	TI,	sys_semget,		"semget"	}, /* 320 */
+	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 321 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 322 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 323 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 324 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 325 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 326 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 327 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 328 */
+	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 329 */
+	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 330 */
+	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 331 */
+	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 332 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 333 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 334 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 335 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 336 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 337 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 338 */
+	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 339 */
+	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 340 */
+	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 341 */
+	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 342 */
+	{ 5,	0,	printargs,		"SYS_343"	}, /* 343 */
+	{ 5,	0,	printargs,		"SYS_344"	}, /* 344 */
+	{ 5,	0,	printargs,		"SYS_345"	}, /* 345 */
+	{ 5,	0,	printargs,		"SYS_346"	}, /* 346 */
+	{ 5,	0,	printargs,		"SYS_347"	}, /* 347 */
