@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.h,v 1.30 2003/06/10 03:37:57 roland Exp $
+ *	$Id: syscall.h,v 1.37 2004/04/16 21:48:44 roland Exp $
  */
 
 #include "dummy.h"
@@ -52,6 +52,7 @@ int sys_setreuid(), sys_setregid(), sys_sigsuspend();
 int sys_sigpending(), sys_sethostname(), sys_setrlimit();
 int sys_getrlimit(), sys_getrusage(), sys_gettimeofday();
 int sys_settimeofday(), sys_getgroups(), sys_setgroups();
+int sys_setgroups32(), sys_getgroups32();
 int sys_oldselect(), sys_symlink(), sys_oldlstat(), sys_readlink();
 int sys_uselib(), sys_swapon(), sys_reboot(), sys_readdir();
 int sys_mmap(), sys_munmap(), sys_truncate(), sys_ftruncate();
@@ -92,7 +93,9 @@ int sys_set_thread_area(), sys_get_thread_area(), sys_remap_file_pages();
 int sys_timer_create(), sys_timer_delete(), sys_timer_getoverrun();
 int sys_timer_gettime(), sys_timer_settime(), sys_clock_settime();
 int sys_clock_gettime(), sys_clock_getres(), sys_clock_nanosleep();
-int sys_semtimedop();
+int sys_semtimedop(), sys_statfs64(), sys_fstatfs64(), sys_tgkill();
+int sys_mq_open(), sys_mq_timedsend(), sys_mq_timedreceive();
+int sys_mq_notify(), sys_mq_getsetattr();
 
 
 /* sys_socketcall subcalls */
@@ -147,11 +150,7 @@ int sys_osf_utimes();
 #  undef SYS_sendmsg
 #  undef SYS_recvmsg
 # endif /* IA64 */
-# if defined POWERPC
-#  define SYS_socket_subcall	256
-# else
 #  define SYS_socket_subcall	300
-# endif
 #define SYS_socket		(SYS_socket_subcall + 1)
 #define SYS_bind		(SYS_socket_subcall + 2)
 #define SYS_connect		(SYS_socket_subcall + 3)
