@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.18 2003/04/08 01:46:51 roland Exp $
+ *	$Id: syscallent.h,v 1.26 2004/04/16 21:48:44 roland Exp $
  */
 
 	{ 0,	0,	sys_setup,		"setup"		}, /* 0 */
@@ -186,7 +186,7 @@
 	{ 1,	0,	sys_getsid,		"getsid"	}, /* 147 */
 	{ 1,	0,	sys_fdatasync,		"fdatasync"	}, /* 148 */
 	{ 1,	0,	sys_sysctl,		"_sysctl"	}, /* 149 */
-	{ 1,	0,	sys_mlock,		"mlock"		}, /* 150 */
+	{ 2,	0,	sys_mlock,		"mlock"		}, /* 150 */
 	{ 2,	0,	sys_munlock,		"munlock"	}, /* 151 */
 	{ 2,	0,	sys_mlockall,		"mlockall"	}, /* 152 */
 	{ 0,	0,	sys_munlockall,		"munlockall"	}, /* 153 */
@@ -238,31 +238,31 @@
 	{ 0,	TP,	sys_vfork,		"vfork"		}, /* 190 */
 	{ 2,	0,	sys_getrlimit,		"getrlimit"	}, /* 191 */
 	{ 6,	0,	sys_mmap,		"mmap2"		}, /* 192 */
-	{ 2,	TF,	sys_truncate64,		"truncate64"	}, /* 193 */
-	{ 2,	TF,	sys_ftruncate64,	"ftruncate64"	}, /* 194 */
+	{ 3,	TF,	sys_truncate64,		"truncate64"	}, /* 193 */
+	{ 3,	TF,	sys_ftruncate64,	"ftruncate64"	}, /* 194 */
 	{ 2,	TF,	sys_stat64,		"stat64"	}, /* 195 */
 	{ 2,	TF,	sys_lstat64,		"lstat64"	}, /* 196 */
 	{ 2,	TF,	sys_fstat64,		"fstat64"	}, /* 197 */
 	{ 3,	TF,	sys_chown,		"lchown32"	}, /* 198 */
 	{ 0,	0,	sys_getuid,		"getuid32"	}, /* 199 */
 
-	{ 0,	0,	printargs,		"getgid32"	}, /* 200 */
-	{ 0,	0,	printargs,		"geteuid32"	}, /* 201 */
-	{ 0,	0,	printargs,		"getegid32"	}, /* 202 */
-	{ 2,	0,	printargs,		"setreuid32"	}, /* 203 */
-	{ 2,	0,	printargs,		"setregid32"	}, /* 204 */
-	{ 2,	0,	printargs,		"getgroups32"	}, /* 205 */
-	{ 2,	0,	printargs,		"setgroups32"	}, /* 206 */
-	{ 3,	0,	printargs,		"fchown32"	}, /* 207 */
-	{ 3,	0,	printargs,		"setresuid32"	}, /* 208 */
-	{ 3,	0,	printargs,		"getresuid32"	}, /* 209 */
-	{ 3,	0,	printargs,		"setresgid32"	}, /* 210 */
-	{ 3,	0,	printargs,		"getresgid32"	}, /* 211 */
-	{ 3,	TF,	printargs,		"chown32"	}, /* 212 */
-	{ 1,	0,	printargs,		"setuid32"	}, /* 213 */
-	{ 1,	0,	printargs,		"setgid32"	}, /* 214 */
-	{ 1,	0,	printargs,		"setfsuid32"	}, /* 215 */
-	{ 1,	0,	printargs,		"setfsgid32"	}, /* 216 */
+	{ 0,	0,	sys_getgid,		"getgid32"	}, /* 200 */
+	{ 0,	0,	sys_geteuid,		"geteuid32"	}, /* 201 */
+	{ 0,	0,	sys_geteuid,		"getegid32"	}, /* 202 */
+	{ 2,	0,	sys_setreuid,		"setreuid32"	}, /* 203 */
+	{ 2,	0,	sys_setregid,		"setregid32"	}, /* 204 */
+	{ 2,	0,	sys_getgroups32,	"getgroups32"	}, /* 205 */
+	{ 2,	0,	sys_setgroups32,	"setgroups32"	}, /* 206 */
+	{ 3,	0,	sys_fchown,		"fchown32"	}, /* 207 */
+	{ 3,	0,	sys_setresuid,		"setresuid32"	}, /* 208 */
+	{ 3,	0,	sys_getresuid,		"getresuid32"	}, /* 209 */
+	{ 3,	0,	sys_setresgid,		"setresgid32"	}, /* 210 */
+	{ 3,	0,	sys_getresgid,		"getresgid32"	}, /* 211 */
+	{ 3,	TF,	sys_chown,		"chown32"	}, /* 212 */
+	{ 1,	0,	sys_setuid,		"setuid32"	}, /* 213 */
+	{ 1,	0,	sys_setgid,		"setgid32"	}, /* 214 */
+	{ 1,	0,	sys_setfsuid,		"setfsuid32"	}, /* 215 */
+	{ 1,	0,	sys_setfsgid,		"setfsgid32"	}, /* 216 */
 	{ 2,	TF,	sys_pivotroot,		"pivot_root"	}, /* 217 */
 	{ 3,	0,	printargs,		"mincore"	}, /* 218 */
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 219 */
@@ -286,7 +286,7 @@
 	{ 2,	0,	sys_fremovexattr,	"fremovexattr"	}, /* 237 */
 	{ 2,	TS,	sys_kill,		"tkill"		}, /* 238 */
 	{ 4,	TF,	sys_sendfile64,		"sendfile64"	}, /* 239 */
-	{ 4,	0,	sys_futex,		"futex"		}, /* 240 */
+	{ 5,	0,	sys_futex,		"futex"		}, /* 240 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity" },/* 241 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity" },/* 242 */
 	{ 1,	0,	sys_set_thread_area,	"set_thread_area" }, /* 243 */
@@ -314,21 +314,21 @@
 	{ 2,	0,	sys_clock_gettime,	"clock_gettime"	}, /* 265 */
 	{ 2,	0,	sys_clock_getres,	"clock_getres"	}, /* 266 */
 	{ 4,	0,	sys_clock_nanosleep,	"clock_nanosleep"}, /* 267 */
-	{ 5,	0,	printargs,		"SYS_268"	}, /* 268 */
-	{ 5,	0,	printargs,		"SYS_269"	}, /* 269 */
-	{ 5,	0,	printargs,		"SYS_270"	}, /* 270 */
-	{ 5,	0,	printargs,		"SYS_271"	}, /* 271 */
+	{ 3,	TF,	sys_statfs64,		"statfs64"	}, /* 268 */
+	{ 3,	0,	sys_fstatfs64,		"fstatfs64"	}, /* 269 */
+	{ 3,	TS,	sys_tgkill,		"tgkill"	}, /* 270 */
+	{ 2,	TF,	sys_utimes,		"utimes"	}, /* 271 */
 	{ 5,	0,	printargs,		"SYS_272"	}, /* 272 */
 	{ 5,	0,	printargs,		"SYS_273"	}, /* 273 */
 	{ 5,	0,	printargs,		"SYS_274"	}, /* 274 */
 	{ 5,	0,	printargs,		"SYS_275"	}, /* 275 */
 	{ 5,	0,	printargs,		"SYS_276"	}, /* 276 */
-	{ 5,	0,	printargs,		"SYS_277"	}, /* 277 */
-	{ 5,	0,	printargs,		"SYS_278"	}, /* 278 */
-	{ 5,	0,	printargs,		"SYS_279"	}, /* 279 */
-	{ 5,	0,	printargs,		"SYS_280"	}, /* 280 */
-	{ 5,	0,	printargs,		"SYS_281"	}, /* 281 */
-	{ 5,	0,	printargs,		"SYS_282"	}, /* 282 */
+	{ 4,	0,	sys_mq_open,		"mq_open"	}, /* 277 */
+	{ 1,	0,	sys_mq_unlink,		"mq_unlink"	}, /* 278 */
+	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"	}, /* 279 */
+	{ 5,	0,	sys_mq_timedreceive,	"mq_timedreceive" }, /* 280 */
+	{ 2,	0,	sys_mq_notify,		"mq_notify"	}, /* 281 */
+	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"	}, /* 282 */
 	{ 5,	0,	printargs,		"SYS_283"	}, /* 283 */
 	{ 5,	0,	printargs,		"SYS_284"	}, /* 284 */
 	{ 5,	0,	printargs,		"SYS_285"	}, /* 285 */
