@@ -29,20 +29,23 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: mem.c,v 1.27 2003/06/02 19:18:58 roland Exp $
+ *	$Id: mem.c,v 1.31 2004/03/02 06:16:59 roland Exp $
  */
 
 #include "defs.h"
 
 #ifdef LINUX
-#include <linux/mman.h>
+#include <asm/mman.h>
 #endif
 #include <sys/mman.h>
 
 #if defined(LINUX) && defined(I386)
 #include <asm/ldt.h>
+# ifdef HAVE_STRUCT_USER_DESC
+#  define modify_ldt_ldt_s user_desc
+# endif
 #endif
-#if defined(LINUX) && defined(SHMEDIA)
+#if defined(LINUX) && defined(SH64)
 #include <asm/page.h>	    /* for PAGE_SHIFT */
 #endif
 
@@ -82,6 +85,15 @@ static struct xlat mmap_prot[] = {
 	{ PROT_READ,	"PROT_READ"	},
 	{ PROT_WRITE,	"PROT_WRITE"	},
 	{ PROT_EXEC,	"PROT_EXEC"	},
+#ifdef PROT_SEM
+	{ PROT_SEM,	"PROT_SEM"	},
+#endif
+#ifdef PROT_GROWSDOWN
+	{ PROT_GROWSDOWN,"PROT_GROWSDOWN"},
+#endif
+#ifdef PROT_GROWSUP
+	{ PROT_GROWSUP, "PROT_GROWSUP"	},
+#endif
 	{ 0,		NULL		},
 };
 
@@ -227,7 +239,7 @@ struct tcb *tcp;
 		return 0;
 	else
 		u_arg[i] = v;
-#elif defined(SH) || defined(SHMEDIA)
+#elif defined(SH) || defined(SH64)
     /* SH has always passed the args in registers */
     int i;
     for (i=0; i<6; i++)
@@ -245,7 +257,7 @@ int
 sys_mmap(tcp)
 struct tcb *tcp;
 {
-#if defined(LINUX) && defined(SHMEDIA)
+#if defined(LINUX) && defined(SH64)
     /*
      * Old mmap differs from new mmap in specifying the
      * offset in units of bytes rather than pages.  We
