@@ -34,7 +34,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: process.c,v 1.67 2003/06/03 23:29:05 roland Exp $
+ *	$Id: process.c,v 1.84 2004/06/04 01:50:45 roland Exp $
  */
 
 #include "defs.h"
@@ -82,7 +82,15 @@
 
 #ifdef HAVE_LINUX_PTRACE_H
 #undef PTRACE_SYSCALL
+# ifdef HAVE_STRUCT_IA64_FPREG
+#  define ia64_fpreg XXX_ia64_fpreg
+# endif
+# ifdef HAVE_STRUCT_PT_ALL_USER_REGS
+#  define pt_all_user_regs XXX_pt_all_user_regs
+# endif
 #include <linux/ptrace.h>
+# undef ia64_fpreg
+# undef pt_all_user_regs
 #endif
 
 #ifdef HAVE_LINUX_FUTEX_H
@@ -98,12 +106,18 @@
 # ifndef FUTEX_FD
 #  define FUTEX_FD 2
 # endif
+# ifndef FUTEX_REQUEUE
+#  define FUTEX_REQUEUE 3
+# endif
 #endif
 
 #ifdef LINUX
+#include <sched.h>
 #include <asm/posix_types.h>
 #undef GETGROUPS_T
 #define GETGROUPS_T __kernel_gid_t
+#undef GETGROUPS32_T
+#define GETGROUPS32_T __kernel_gid32_t
 #endif /* LINUX */
 
 #if defined(LINUX) && defined(IA64)
@@ -368,6 +382,12 @@ struct tcb *tcp;
 	if (entering(tcp)) {
 		tcp->flags |= TCB_EXITING;
 #ifdef __NR_exit_group
+# ifdef IA64
+		if (ia32) {
+			if (tcp->scno == 252)
+				tcp->flags |= TCB_GROUP_EXITING;
+		} else
+# endif
 		if (tcp->scno == __NR_exit_group)
 			tcp->flags |= TCB_GROUP_EXITING;
 #endif
@@ -382,27 +402,10 @@ static int
 fork_tcb(struct tcb *tcp)
 {
 	if (nprocs == tcbtabsize) {
-		/* Allocate some more TCBs and expand the table.
-		   We don't want to relocate the TCBs because our
-		   callers have pointers and it would be a pain.
-		   So tcbtab is a table of pointers.  Since we never
-		   free the TCBs, we allocate a single chunk of many.  */
-		struct tcb **newtab = (struct tcb **)
-			realloc(tcbtab, 2 * tcbtabsize * sizeof tcbtab[0]);
-		struct tcb *newtcbs = (struct tcb *) calloc(tcbtabsize,
-							    sizeof *newtcbs);
-		int i;
-		if (newtab == NULL || newtcbs == NULL) {
-			if (newtab != NULL)
-				free(newtab);
+		if (expand_tcbtab()) {
 			tcp->flags &= ~TCB_FOLLOWFORK;
 			fprintf(stderr, "sys_fork: tcb table full\n");
-			return 1;
 		}
-		for (i = tcbtabsize; i < 2 * tcbtabsize; ++i)
-			newtab[i] = &newtcbs[i - tcbtabsize];
-		tcbtabsize *= 2;
-		tcbtab = newtab;
 	}
 
 	tcp->flags |= TCB_FOLLOWFORK;
@@ -522,6 +525,9 @@ static struct xlat clone_flags[] = {
 
 # ifdef I386
 #  include <asm/ldt.h>
+#   ifdef HAVE_STRUCT_USER_DESC
+#    define modify_ldt_ldt_s user_desc
+#   endif
 extern void print_ldt_entry();
 # endif
 
@@ -538,7 +544,7 @@ extern void print_ldt_entry();
 #  define ARG_PTID	2
 #  define ARG_CTID	3
 #  define ARG_TLS	4
-# elif defined X86_64
+# elif defined X86_64 || defined ALPHA
 #  define ARG_FLAGS	0
 #  define ARG_STACK	1
 #  define ARG_PTID	2
@@ -652,7 +658,18 @@ int new;
 	    	return -1;
 	return 0;
 #elif defined(IA64)
-	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(PT_R15), new)<0)
+	if (ia32) {
+		switch (new) {
+		      case 2: break;	/* x86 SYS_fork */
+		      case SYS_clone:	new = 120; break;
+		      default:
+			fprintf(stderr, "%s: unexpected syscall %d\n",
+				__FUNCTION__, new);
+			return -1;
+		}
+		if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(PT_R1), new)<0)
+			return -1;
+	} else if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(PT_R15), new)<0)
 		return -1;
 	return 0;
 #elif defined(HPPA)
@@ -663,7 +680,7 @@ int new;
        if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(4*(REG_REG0+3)), new)<0)
                return -1;
        return 0;
-#elif defined(SHMEDIA)
+#elif defined(SH64)
        /* Top half of reg encodes the no. of args n as 0x1n.
           Assume 0 args as kernel never actually checks... */
        if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(REG_SYSCALL),
@@ -1106,15 +1123,15 @@ sys_getresuid(tcp)
 			if (umove(tcp, tcp->u_arg[0], &uid) < 0)
 				tprintf("%#lx, ", tcp->u_arg[0]);
 			else
-				tprintf("ruid %lu, ", (unsigned long) uid);
+				tprintf("[%lu], ", (unsigned long) uid);
 			if (umove(tcp, tcp->u_arg[1], &uid) < 0)
 				tprintf("%#lx, ", tcp->u_arg[1]);
 			else
-				tprintf("euid %lu, ", (unsigned long) uid);
+				tprintf("[%lu], ", (unsigned long) uid);
 			if (umove(tcp, tcp->u_arg[2], &uid) < 0)
 				tprintf("%#lx", tcp->u_arg[2]);
 			else
-				tprintf("suid %lu", (unsigned long) uid);
+				tprintf("[%lu]", (unsigned long) uid);
 		}
 	}
 	return 0;
@@ -1133,15 +1150,15 @@ struct tcb *tcp;
 			if (umove(tcp, tcp->u_arg[0], &gid) < 0)
 				tprintf("%#lx, ", tcp->u_arg[0]);
 			else
-				tprintf("rgid %lu, ", (unsigned long) gid);
+				tprintf("[%lu], ", (unsigned long) gid);
 			if (umove(tcp, tcp->u_arg[1], &gid) < 0)
 				tprintf("%#lx, ", tcp->u_arg[1]);
 			else
-				tprintf("egid %lu, ", (unsigned long) gid);
+				tprintf("[%lu], ", (unsigned long) gid);
 			if (umove(tcp, tcp->u_arg[2], &gid) < 0)
 				tprintf("%#lx", tcp->u_arg[2]);
 			else
-				tprintf("sgid %lu", (unsigned long) gid);
+				tprintf("[%lu]", (unsigned long) gid);
 		}
 	}
 	return 0;
@@ -1154,9 +1171,8 @@ sys_setreuid(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		tprintf("%lu, %lu",
-			(unsigned long) (uid_t) tcp->u_arg[0],
-			(unsigned long) (uid_t) tcp->u_arg[1]);
+		printuid("", tcp->u_arg[0]);
+		printuid(", ", tcp->u_arg[1]);
 	}
 	return 0;
 }
@@ -1166,9 +1182,8 @@ sys_setregid(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		tprintf("%lu, %lu",
-			(unsigned long) (gid_t) tcp->u_arg[0],
-			(unsigned long) (gid_t) tcp->u_arg[1]);
+		printuid("", tcp->u_arg[0]);
+		printuid(", ", tcp->u_arg[1]);
 	}
 	return 0;
 }
@@ -1179,10 +1194,9 @@ sys_setresuid(tcp)
      struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		tprintf("ruid %u, euid %u, suid %u",
-				(uid_t) tcp->u_arg[0],
-				(uid_t) tcp->u_arg[1],
-				(uid_t) tcp->u_arg[2]);
+		printuid("", tcp->u_arg[0]);
+		printuid(", ", tcp->u_arg[1]);
+		printuid(", ", tcp->u_arg[2]);
 	}
 	return 0;
 }
@@ -1191,10 +1205,9 @@ sys_setresgid(tcp)
      struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		tprintf("rgid %u, egid %u, sgid %u",
-				(uid_t) tcp->u_arg[0],
-				(uid_t) tcp->u_arg[1],
-				(uid_t) tcp->u_arg[2]);
+		printuid("", tcp->u_arg[0]);
+		printuid(", ", tcp->u_arg[1]);
+		printuid(", ", tcp->u_arg[2]);
 	}
 	return 0;
 }
@@ -1277,6 +1290,84 @@ struct tcb *tcp;
 	return 0;
 }
 
+#ifdef LINUX
+int
+sys_setgroups32(tcp)
+struct tcb *tcp;
+{
+	int i, len;
+	GETGROUPS32_T *gidset;
+
+	if (entering(tcp)) {
+		len = tcp->u_arg[0];
+		tprintf("%u, ", len);
+		if (len <= 0) {
+			tprintf("[]");
+			return 0;
+		}
+		gidset = (GETGROUPS32_T *) malloc(len * sizeof(GETGROUPS32_T));
+		if (gidset == NULL) {
+			fprintf(stderr, "sys_setgroups32: out of memory\n");
+			return -1;
+		}
+		if (!verbose(tcp))
+			tprintf("%#lx", tcp->u_arg[1]);
+		else if (umoven(tcp, tcp->u_arg[1],
+		    len * sizeof(GETGROUPS32_T), (char *) gidset) < 0)
+			tprintf("[?]");
+		else {
+			tprintf("[");
+			for (i = 0; i < len; i++)
+				tprintf("%s%lu", i ? ", " : "",
+					(unsigned long) gidset[i]);
+			tprintf("]");
+		}
+		free((char *) gidset);
+	}
+	return 0;
+}
+
+int
+sys_getgroups32(tcp)
+struct tcb *tcp;
+{
+	int i, len;
+	GETGROUPS32_T *gidset;
+
+	if (entering(tcp)) {
+		len = tcp->u_arg[0];
+		tprintf("%u, ", len);
+	} else {
+		len = tcp->u_rval;
+		if (len <= 0) {
+			tprintf("[]");
+			return 0;
+		}
+		gidset = (GETGROUPS32_T *) malloc(len * sizeof(GETGROUPS32_T));
+		if (gidset == NULL) {
+			fprintf(stderr, "sys_getgroups32: out of memory\n");
+			return -1;
+		}
+		if (!tcp->u_arg[1])
+			tprintf("NULL");
+		else if (!verbose(tcp) || tcp->u_arg[0] == 0)
+			tprintf("%#lx", tcp->u_arg[1]);
+		else if (umoven(tcp, tcp->u_arg[1],
+		    len * sizeof(GETGROUPS32_T), (char *) gidset) < 0)
+			tprintf("[?]");
+		else {
+			tprintf("[");
+			for (i = 0; i < len; i++)
+				tprintf("%s%lu", i ? ", " : "",
+					(unsigned long) gidset[i]);
+			tprintf("]");
+		}
+		free((char *)gidset);
+	}
+	return 0;
+}
+#endif /* LINUX */
+
 int
 sys_setpgrp(tcp)
 struct tcb *tcp;
@@ -1599,7 +1690,10 @@ struct tcb *tcp;
 		}
 	}
 #if defined LINUX && defined TCB_WAITEXECVE
-	tcp->flags |= TCB_WAITEXECVE;
+	if (exiting(tcp) && syserror(tcp))
+		tcp->flags &= ~TCB_WAITEXECVE;
+	else
+		tcp->flags |= TCB_WAITEXECVE;
 #endif /* LINUX && TCB_WAITEXECVE */
 	return 0;
 }
@@ -1684,20 +1778,33 @@ int status;
 	 * is still not entirely satisfactory but since there
 	 * are no wait status constructors it will have to do.
 	 */
-	if (WIFSTOPPED(status))
-		tprintf("[WIFSTOPPED(s) && WSTOPSIG(s) == %s]",
+	if (WIFSTOPPED(status)) {
+		tprintf("[{WIFSTOPPED(s) && WSTOPSIG(s) == %s}",
 			signame(WSTOPSIG(status)));
-	else if WIFSIGNALED(status)
-		tprintf("[WIFSIGNALED(s) && WTERMSIG(s) == %s%s]",
+		status &= ~W_STOPCODE(WSTOPSIG(status));
+	}
+	else if (WIFSIGNALED(status)) {
+		tprintf("[{WIFSIGNALED(s) && WTERMSIG(s) == %s%s}",
 			signame(WTERMSIG(status)),
 			WCOREDUMP(status) ? " && WCOREDUMP(s)" : "");
-	else if WIFEXITED(status) {
-		tprintf("[WIFEXITED(s) && WEXITSTATUS(s) == %d]",
+		status &= ~(W_EXITCODE(0, WTERMSIG(status)) | WCOREFLAG);
+	}
+	else if (WIFEXITED(status)) {
+		tprintf("[{WIFEXITED(s) && WEXITSTATUS(s) == %d}",
 			WEXITSTATUS(status));
 		exited = 1;
+		status &= ~W_EXITCODE(WEXITSTATUS(status), 0);
 	}
-	else
+	else {
 		tprintf("[%#x]", status);
+		return 0;
+	}
+
+	if (status == 0)
+		tprintf("]");
+	else
+		tprintf(" | %#x]", status);
+
 	return exited;
 }
 
@@ -1788,10 +1895,30 @@ struct tcb *tcp;
 			 * we shouldn't block if there are zombies to reap.
 			 * XXX doesn't handle pgrp matches (u_arg[0]==0,<-1)
 			 */
+			struct tcb *child = NULL;
 			if (tcp->nzombies > 0 &&
 			    (tcp->u_arg[0] == -1 ||
-			     pid2tcb(tcp->u_arg[0]) == NULL))
+			     (child = pid2tcb(tcp->u_arg[0])) == NULL))
 				return 0;
+			if (tcp->u_arg[0] > 0) {
+				/*
+				 * If the parent waits for a specified child
+				 * PID, then it must get ECHILD right away
+				 * if that PID is not one of its children.
+				 * Make sure that the requested PID matches
+				 * one of the parent's children that we are
+				 * tracing, and don't suspend it otherwise.
+				 */
+				if (child == NULL)
+					child = pid2tcb(tcp->u_arg[0]);
+				if (child == NULL || child->parent != (
+#ifdef TCB_CLONE_THREAD
+					    (tcp->flags & TCB_CLONE_THREAD)
+					    ? tcp->parent :
+#endif
+					    tcp))
+					return 0;
+			}
 			tcp->flags |= TCB_SUSPENDED;
 			tcp->waitpid = tcp->u_arg[0];
 #ifdef TCB_CLONE_THREAD
@@ -1807,10 +1934,6 @@ struct tcb *tcp;
 			extern int force_result();
 			return force_result(tcp, 0, 0);
 		}
-		else
-			fprintf(stderr,
-				"internal_wait: should not have resumed %d\n",
-				tcp->pid);
 	}
 	else if (exiting(tcp) && tcp->u_error == 0 && tcp->u_rval > 0 &&
 		 tcp->nzombies > 0 && pid2tcb(tcp->u_rval) == NULL) {
@@ -2325,16 +2448,12 @@ struct xlat struct_user_offsets[] = {
 	{ PT_F27, "f27" }, { PT_F28, "f28" }, { PT_F29, "f29" },
 	{ PT_F30, "f30" }, { PT_F31, "f31" }, { PT_R4, "r4" },
 	{ PT_R5, "r5" }, { PT_R6, "r6" }, { PT_R7, "r7" },
-	{ PT_B0, "kb0" },
 	{ PT_B1, "b1" }, { PT_B2, "b2" }, { PT_B3, "b3" },
 	{ PT_B4, "b4" }, { PT_B5, "b5" },
-	{ PT_AR_PFS, "kar.pfs" },
-	{ PT_AR_LC, "ar.lc" }, { PT_AR_UNAT, "kar.unat" },
-	{ PT_AR_RNAT, "kar.rnat" }, { PT_AR_BSPSTORE, "kar.bspstore" },
-	{ PT_PR, "k.pr" },
+	{ PT_AR_EC, "ar.ec" }, { PT_AR_LC, "ar.lc" },
 	/* pt_regs */
-	{ PT_CR_IPSR, "cr.ipsr" }, { PT_CR_IIP, "cr.iip" },
-	/*{ PT_CR_IFS, "cr.ifs" },*/ { PT_AR_UNAT, "ar.unat" },
+	{ PT_CR_IPSR, "psr" }, { PT_CR_IIP, "ip" },
+	{ PT_CFM, "cfm" }, { PT_AR_UNAT, "ar.unat" },
 	{ PT_AR_PFS, "ar.pfs" }, { PT_AR_RSC, "ar.rsc" },
 	{ PT_AR_RNAT, "ar.rnat" }, { PT_AR_BSPSTORE, "ar.bspstore" },
 	{ PT_PR, "pr" }, { PT_B6, "b6" }, { PT_AR_BSP, "ar.bsp" },
@@ -2350,6 +2469,13 @@ struct xlat struct_user_offsets[] = {
 	{ PT_AR_CCV, "ar.ccv" }, { PT_AR_FPSR, "ar.fpsr" },
 	{ PT_B0, "b0" }, { PT_B7, "b7" }, { PT_F6, "f6" },
 	{ PT_F7, "f7" }, { PT_F8, "f8" }, { PT_F9, "f9" },
+# ifdef PT_AR_CSD
+	{ PT_AR_CSD, "ar.csd" },
+# endif
+# ifdef PT_AR_SSD
+	{ PT_AR_SSD, "ar.ssd" },
+# endif
+	{ PT_DBR, "dbr" }, { PT_IBR, "ibr" }, { PT_PMD, "pmd" },
 #else /* !IA64 */
 #ifdef I386
 	{ 4*EBX,		"4*EBX"					},
@@ -2462,6 +2588,7 @@ struct xlat struct_user_offsets[] = {
        { 4*(REG_FPREG0+13),    "4*REG_FPREG13"                         },
        { 4*(REG_FPREG0+14),    "4*REG_FPREG14"                         },
        { 4*REG_FPREG15,        "4*REG_FPREG15"                         },
+#ifdef REG_XDREG0
        { 4*REG_XDREG0,         "4*REG_XDREG0"                          },
        { 4*(REG_XDREG0+2),     "4*REG_XDREG2"                          },
        { 4*(REG_XDREG0+4),     "4*REG_XDREG4"                          },
@@ -2470,9 +2597,10 @@ struct xlat struct_user_offsets[] = {
        { 4*(REG_XDREG0+10),    "4*REG_XDREG10"                         },
        { 4*(REG_XDREG0+12),    "4*REG_XDREG12"                         },
        { 4*REG_XDREG14,        "4*REG_XDREG14"                         },
+#endif
        { 4*REG_FPSCR,          "4*REG_FPSCR"                           },
 #endif /* SH */
-#ifdef SHMEDIA
+#ifdef SH64
 	{ 0,		        "PC(L)"				        },
 	{ 4,	                "PC(U)"				        },
 	{ 8, 	                "SR(L)"	  	         		},
@@ -2660,12 +2788,12 @@ struct xlat struct_user_offsets[] = {
 	{ uoff(u_dsize),	"offsetof(struct user, u_dsize)"	},
 	{ uoff(u_ssize),	"offsetof(struct user, u_ssize)"	},
 	{ uoff(start_code),	"offsetof(struct user, start_code)"	},
-#ifdef SHMEDIA
+#ifdef SH64
 	{ uoff(start_data),	"offsetof(struct user, start_data)"	},
 #endif
 	{ uoff(start_stack),	"offsetof(struct user, start_stack)"	},
 	{ uoff(signal),		"offsetof(struct user, signal)"		},
-#if !defined(S390) && !defined(S390X) && !defined(MIPS) && !defined(SH) && !defined(SHMEDIA)
+#if !defined(S390) && !defined(S390X) && !defined(MIPS) && !defined(SH) && !defined(SH64)
 	{ uoff(reserved),	"offsetof(struct user, reserved)"	},
 #endif
 	{ uoff(u_ar0),		"offsetof(struct user, u_ar0)"		},
@@ -2828,6 +2956,7 @@ static struct xlat futexops[] = {
 	{ FUTEX_WAIT,	"FUTEX_WAIT" },
 	{ FUTEX_WAKE,	"FUTEX_WAKE" },
 	{ FUTEX_FD,	"FUTEX_FD" },
+	{ FUTEX_REQUEUE,"FUTEX_REQUEUE" },
 	{ 0,		NULL }
 };
 
@@ -2837,27 +2966,32 @@ struct tcb *tcp;
 {
     if (entering(tcp)) {
 	tprintf("%p, ", (void *) tcp->u_arg[0]);
-	printflags(futexops, tcp->u_arg[1]);
+	printxval(futexops, tcp->u_arg[1], "FUTEX_???");
 	tprintf(", %ld", tcp->u_arg[2]);
 	if (tcp->u_arg[1] == FUTEX_WAIT) {
 		tprintf(", ");
 		printtv(tcp, tcp->u_arg[3]);
-	}
+	} else if (tcp->u_arg[1] == FUTEX_REQUEUE)
+		tprintf(", %ld, %p", tcp->u_arg[3], (void *) tcp->u_arg[4]);
     }
     return 0;
 }
 
 static void
-print_affinitylist(list, len)
-unsigned long *list;
+print_affinitylist(tcp, list, len)
+struct tcb *tcp;
+long list;
 unsigned int len;
 {
     int first = 1;
     tprintf(" {");
     while (len >= sizeof (unsigned long)) {
-	tprintf("%s %lx", first ? "" : ",", *list++);
+	unsigned long w;
+	umove(tcp, list, &w);
+	tprintf("%s %lx", first ? "" : ",", w);
 	first = 0;
 	len -= sizeof (unsigned long);
+	list += sizeof(unsigned long);
     }
     tprintf(" }");
 }
@@ -2868,7 +3002,7 @@ struct tcb *tcp;
 {
     if (entering(tcp)) {
 	tprintf("%ld, %lu, ", tcp->u_arg[0], tcp->u_arg[1]);
-	print_affinitylist((unsigned long *) tcp->u_arg[2], tcp->u_arg[1]);
+	print_affinitylist(tcp, tcp->u_arg[2], tcp->u_arg[1]);
     }
     return 0;
 }
@@ -2880,7 +3014,87 @@ struct tcb *tcp;
     if (entering(tcp)) {
 	tprintf("%ld, %lu, ", tcp->u_arg[0], tcp->u_arg[1]);
     } else {
-	print_affinitylist((unsigned long *) tcp->u_arg[2], tcp->u_rval);
+	if (tcp->u_rval == -1)
+	    tprintf("%#lx", tcp->u_arg[2]);
+	else
+	    print_affinitylist(tcp, tcp->u_arg[2], tcp->u_rval);
+    }
+    return 0;
+}
+
+static struct xlat schedulers[] = {
+	{ SCHED_OTHER,	"SCHED_OTHER" },
+	{ SCHED_RR,	"SCHED_RR" },
+	{ SCHED_FIFO,	"SCHED_FIFO" },
+	{ 0,		NULL }
+};
+
+int
+sys_sched_getscheduler(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	tprintf("%d", (int) tcp->u_arg[0]);
+    } else if (! syserror(tcp)) {
+	tcp->auxstr = xlookup (schedulers, tcp->u_rval);
+	if (tcp->auxstr != NULL)
+	    return RVAL_STR;
+    }
+    return 0;
+}
+
+int
+sys_sched_setscheduler(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	struct sched_param p;
+	tprintf("%d, ", (int) tcp->u_arg[0]);
+	printxval(schedulers, tcp->u_arg[1], "SCHED_???");
+	if (umove(tcp, tcp->u_arg[2], &p) < 0)
+	    tprintf(", %lx", tcp->u_arg[2]);
+	else
+	    tprintf(", { %d }", p.__sched_priority);
+    }
+    return 0;
+}
+
+int
+sys_sched_getparam(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	    tprintf("%d, ", (int) tcp->u_arg[0]);
+    } else {
+	struct sched_param p;
+	if (umove(tcp, tcp->u_arg[1], &p) < 0)
+	    tprintf("%lx", tcp->u_arg[1]);
+	else
+	    tprintf("{ %d }", p.__sched_priority);
+    }
+    return 0;
+}
+
+int
+sys_sched_setparam(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	struct sched_param p;
+	if (umove(tcp, tcp->u_arg[1], &p) < 0)
+	    tprintf("%d, %lx", (int) tcp->u_arg[0], tcp->u_arg[1]);
+	else
+	    tprintf("%d, { %d }", (int) tcp->u_arg[0], p.__sched_priority);
+    }
+    return 0;
+}
+
+int
+sys_sched_get_priority_min(tcp)
+struct tcb *tcp;
+{
+    if (entering(tcp)) {
+	printxval(schedulers, tcp->u_arg[0], "SCHED_???");
     }
     return 0;
 }
