@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: signal.c,v 1.42 2003/06/03 23:29:05 roland Exp $
+ *	$Id: signal.c,v 1.46 2004/03/01 21:31:02 roland Exp $
  */
 
 #include "defs.h"
@@ -53,7 +53,15 @@
 #endif
 #elif defined(HAVE_LINUX_PTRACE_H)
 #undef PTRACE_SYSCALL
+# ifdef HAVE_STRUCT_IA64_FPREG
+#  define ia64_fpreg XXX_ia64_fpreg
+# endif
+# ifdef HAVE_STRUCT_PT_ALL_USER_REGS
+#  define pt_all_user_regs XXX_pt_all_user_regs
+# endif
 #include <linux/ptrace.h>
+# undef ia64_fpreg
+# undef pt_all_user_regs
 #endif
 
 
@@ -344,6 +352,13 @@ int rt; /* set might include realtime sigs */
 			if (i < nsignals) {
 				sprintf(s, format, signalent[i] + 3);
 			}
+#ifdef SIGRTMIN
+			else if (i >= __SIGRTMIN && i <= __SIGRTMAX) {
+				char tsig[40];
+				sprintf(tsig, "RT_%u", i - __SIGRTMIN);
+				sprintf(s, format, tsig);
+			}
+#endif /* SIGRTMIN */
 			else {
 				char tsig[32];
 				sprintf(tsig, "%u", i);
@@ -758,16 +773,24 @@ int verbose;
 static void
 parse_sigset_t (const char *str, sigset_t *set)
 {
+	const char *p;
 	unsigned int digit;
 	int i;
 
 	sigemptyset(set);
 
-	for (i = _NSIG - 4; i >= 0; i -= 4, ++str) {
-		if (*str >= 'a')
-			digit = (*str - 'a') + 10;
+	p = strchr(str, '\n');
+	if (p == NULL)
+		p = strchr(str, '\0');
+	for (i = 0; p-- > str; i += 4) {
+		if (*p >= '0' && *p <= '9')
+			digit = *p - '0';
+		else if (*p >= 'a' && *p <= 'f')
+			digit = *p - 'a';
+		else if (*p >= 'A' && *p <= 'F')
+			digit = *p - 'A';
 		else
-			digit = *str - '0';
+			break;
 		if (digit & 1)
 			sigaddset(set, i + 1);
 		if (digit & 2)
@@ -1679,6 +1702,19 @@ struct tcb *tcp;
 	return sys_kill(tcp);
 }
 
+#ifdef LINUX
+int
+sys_tgkill(tcp)
+	struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		tprintf("%ld, %ld, %s",
+			tcp->u_arg[0], tcp->u_arg[1], signame(tcp->u_arg[2]));
+	}
+	return 0;
+}
+#endif
+
 int
 sys_sigpending(tcp)
 struct tcb *tcp;
