@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: strace.c,v 1.49 2003/06/10 03:05:53 roland Exp $
+ *	$Id: strace.c,v 1.57 2004/06/04 01:50:45 roland Exp $
  */
 
 #include <sys/types.h>
@@ -44,6 +44,7 @@
 #include <grp.h>
 #include <string.h>
 #include <limits.h>
+#include <dirent.h>
 
 #if defined(IA64) && defined(LINUX)
 # include <asm/ptrace_offsets.h>
@@ -304,6 +305,9 @@ char *argv[];
 		}
 	}
 
+	if (optind == argc && !pflag_seen)
+		usage(stderr, 1);
+
 	/* See if they want to run as another user. */
 	if (username != NULL) {
 		struct passwd *pent;
@@ -331,22 +335,31 @@ char *argv[];
 	setreuid(geteuid(), getuid());
 #endif
 
-	/* See if they want to pipe the output. */
-	if (outfname && (outfname[0] == '|' || outfname[0] == '!')) {
-		if ((outf = popen(outfname + 1, "w")) == NULL) {
-			fprintf(stderr, "%s: can't popen '%s': %s\n",
-				progname, outfname + 1, strerror(errno));
-			exit(1);
-		}
-		free(outfname);
-		outfname = NULL;
-	}
-
 	/* Check if they want to redirect the output. */
 	if (outfname) {
 		long f;
 
-		if ((outf = fopen(outfname, "w")) == NULL) {
+		/* See if they want to pipe the output. */
+		if (outfname[0] == '|' || outfname[0] == '!') {
+			/*
+			 * We can't do the <outfname>.PID funny business
+			 * when using popen, so prohibit it.
+			 */
+			if (followfork > 1) {
+				fprintf(stderr, "\
+%s: piping the output and -ff are mutually exclusive options\n",
+					progname);
+				exit(1);
+			}
+
+			if ((outf = popen(outfname + 1, "w")) == NULL) {
+				fprintf(stderr, "%s: can't popen '%s': %s\n",
+					progname, outfname + 1,
+					strerror(errno));
+				exit(1);
+			}
+		}
+		else if ((outf = fopen(outfname, "w")) == NULL) {
 			fprintf(stderr, "%s: can't fopen '%s': %s\n",
 				progname, outfname, strerror(errno));
 			exit(1);
@@ -367,10 +380,9 @@ char *argv[];
 	setreuid(geteuid(), getuid());
 #endif
 
-	if (!outfname) {
+	if (!outfname || outfname[0] == '|' || outfname[0] == '!')
 		setvbuf(outf, buf, _IOLBF, BUFSIZ);
-	}
-	else if (optind < argc) {
+	if (outfname && optind < argc) {
 		interactive = 0;
 		qflag = 1;
 	}
@@ -388,6 +400,68 @@ char *argv[];
 			continue;
 		}
 #else /* !USE_PROCFS */
+# ifdef LINUX
+		if (tcp->flags & TCB_CLONE_THREAD)
+			continue;
+		if (followfork) {
+			char procdir[MAXPATHLEN];
+			DIR *dir;
+			sprintf(procdir, "/proc/%d/task", tcp->pid);
+			dir = opendir(procdir);
+			if (dir != NULL) {
+				unsigned int ntid = 0, nerr = 0;
+				struct dirent *de;
+				int tid;
+				while ((de = readdir(dir)) != NULL) {
+					if (de->d_fileno == 0 ||
+					    de->d_name[0] == '.')
+						continue;
+					tid = atoi(de->d_name);
+					if (tid <= 0)
+						continue;
+					++ntid;
+					if (ptrace(PTRACE_ATTACH, tid,
+						   (char *) 1, 0) < 0)
+						++nerr;
+					else if (tid != tcbtab[c]->pid) {
+						if (nprocs == tcbtabsize &&
+						    expand_tcbtab())
+							tcp = NULL;
+						else
+							tcp = alloctcb(tid);
+						if (tcp == NULL) {
+							fprintf(stderr, "%s: out of memory\n",
+								progname);
+							exit(1);
+						}
+						tcp->flags |= TCB_ATTACHED|TCB_CLONE_THREAD|TCB_CLONE_DETACHED|TCB_FOLLOWFORK;
+						tcbtab[c]->nchildren++;
+						tcbtab[c]->nclone_threads++;
+						tcbtab[c]->nclone_detached++;
+						tcp->parent = tcbtab[c];
+					}
+				}
+				closedir(dir);
+				if (nerr == ntid) {
+					perror("attach: ptrace(PTRACE_ATTACH, ...)");
+					droptcb(tcp);
+					continue;
+				}
+				if (!qflag) {
+					ntid -= nerr;
+					if (ntid > 1)
+						fprintf(stderr, "\
+Process %u attached with %u threads - interrupt to quit\n",
+							tcp->pid, ntid);
+					else
+						fprintf(stderr, "\
+Process %u attached - interrupt to quit\n",
+							tcp->pid);
+				}
+				continue;
+			}
+		}
+# endif
 		if (ptrace(PTRACE_ATTACH, tcp->pid, (char *) 1, 0) < 0) {
 			perror("attach: ptrace(PTRACE_ATTACH, ...)");
 			droptcb(tcp);
@@ -397,17 +471,23 @@ char *argv[];
 		if (!qflag)
 			fprintf(stderr,
 				"Process %u attached - interrupt to quit\n",
-				pid);
+				tcp->pid);
 	}
 
-	if (optind < argc) {
+	if (!pflag_seen) {
 		struct stat statbuf;
 		char *filename;
 		char pathname[MAXPATHLEN];
 
 		filename = argv[optind];
-		if (strchr(filename, '/'))
+		if (strchr(filename, '/')) {
+			if (strlen(filename) > sizeof pathname - 1) {
+				errno = ENAMETOOLONG;
+				perror("strace: exec");
+				exit(1);
+			}
 			strcpy(pathname, filename);
+		}
 #ifdef USE_DEBUGGING_EXEC
 		/*
 		 * Debuggers customarily check the current directory
@@ -432,6 +512,8 @@ char *argv[];
 					getcwd(pathname, MAXPATHLEN);
 					len = strlen(pathname);
 				}
+				else if (n > sizeof pathname - 1)
+					continue;
 				else {
 					strncpy(pathname, path, n);
 					len = n;
@@ -541,8 +623,6 @@ char *argv[];
 			break;
 		}
 	}
-	else if (pflag_seen == 0)
-		usage(stderr, 1);
 
 	sigemptyset(&empty_set);
 	sigemptyset(&blocked_set);
@@ -612,6 +692,33 @@ struct tcb *tcp;
 	return;
 }
 
+int
+expand_tcbtab()
+{
+	/* Allocate some more TCBs and expand the table.
+	   We don't want to relocate the TCBs because our
+	   callers have pointers and it would be a pain.
+	   So tcbtab is a table of pointers.  Since we never
+	   free the TCBs, we allocate a single chunk of many.  */
+	struct tcb **newtab = (struct tcb **)
+		realloc(tcbtab, 2 * tcbtabsize * sizeof tcbtab[0]);
+	struct tcb *newtcbs = (struct tcb *) calloc(tcbtabsize,
+						    sizeof *newtcbs);
+	int i;
+	if (newtab == NULL || newtcbs == NULL) {
+		if (newtab != NULL)
+			free(newtab);
+		return 1;
+	}
+	for (i = tcbtabsize; i < 2 * tcbtabsize; ++i)
+		newtab[i] = &newtcbs[i - tcbtabsize];
+	tcbtabsize *= 2;
+	tcbtab = newtab;
+
+	return 0;
+}
+
+
 struct tcb *
 alloctcb(pid)
 int pid;
@@ -2013,8 +2120,12 @@ Process %d attached (waiting for parent)\n",
 			if (!cflag
 			    && (qual_flags[WTERMSIG(status)] & QUAL_SIGNAL)) {
 				printleader(tcp);
-				tprintf("+++ killed by %s +++",
-					signame(WTERMSIG(status)));
+				tprintf("+++ killed by %s %s+++",
+					signame(WTERMSIG(status)),
+#ifdef WCOREDUMP
+					WCOREDUMP(status) ? "(core dumped) " :
+#endif
+					"");
 				printtrailer(tcp);
 			}
 #ifdef TCB_GROUP_EXITING
@@ -2213,8 +2324,14 @@ va_dcl
 	va_list args;
 
 	VA_START(args, fmt);
-	if (outf)
-		curcol += vfprintf(outf, fmt, args);
+	if (outf) {
+		int n = vfprintf(outf, fmt, args);
+		if (n < 0 && outf != stderr)
+			perror(outfname == NULL
+			       ? "<writing to pipe>" : outfname);
+		else
+			curcol += n;
+	}
 	va_end(args);
 	return;
 }
