@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: stream.c,v 1.19 2003/04/02 01:10:44 roland Exp $
+ *	$Id: stream.c,v 1.21 2004/01/13 10:18:46 roland Exp $
  */
 
 #include "defs.h"
@@ -932,7 +932,7 @@ struct tcb *tcp;
 int arg;
 {
 	struct strioctl si;
-	char *name;
+	struct ioctlent *iop;
 	int in_and_out;
 	int timod = 0;
 #ifdef SI_GETUDATA
@@ -947,10 +947,12 @@ int arg;
 		return 1;
 	}
 	if (entering(tcp)) {
-		name = ioctl_lookup(si.ic_cmd);
-		if (name)
-			tprintf(", {ic_cmd=%s", name);
-		else
+		iop = ioctl_lookup(si.ic_cmd);
+		if (iop) {
+			tprintf(", {ic_cmd=%s", iop->symbol);
+			while ((iop = ioctl_next_match(iop)))
+				tprintf(" or %s", iop->symbol);
+		} else
 			tprintf(", {ic_cmd=%#x", si.ic_cmd);
 		if (si.ic_timout == INFTIM)
 			tprintf(", ic_timout=INFTIM, ");
