@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.53 2003/06/03 23:29:04 roland Exp $
+ *	$Id: syscall.c,v 1.66 2004/03/02 06:52:01 roland Exp $
  */
 
 #include "defs.h"
@@ -63,7 +63,15 @@
 #endif
 #elif defined(HAVE_LINUX_PTRACE_H)
 #undef PTRACE_SYSCALL
+# ifdef HAVE_STRUCT_IA64_FPREG
+#  define ia64_fpreg XXX_ia64_fpreg
+# endif
+# ifdef HAVE_STRUCT_PT_ALL_USER_REGS
+#  define pt_all_user_regs XXX_pt_all_user_regs
+# endif
 #include <linux/ptrace.h>
+# undef ia64_fpreg
+# undef pt_all_user_regs
 #endif
 
 #if defined(LINUX) && defined(IA64)
@@ -85,6 +93,9 @@
 #ifndef ENOIOCTLCMD
 #define ENOIOCTLCMD	515	/* No ioctl command */
 #endif
+#ifndef ERESTART_RESTARTBLOCK
+#define ERESTART_RESTARTBLOCK 516	/* restart by calling sys_restart_syscall */
+#endif
 #ifndef NSIG
 #define NSIG 32
 #endif
@@ -291,6 +302,8 @@ qual_signal(s, opt, not)
 		qualify_one(atoi(s), opt, not);
 		return 1;
 	}
+	if (strlen(s) >= sizeof buf)
+		return 0;
 	strcpy(buf, s);
 	s = buf;
 	for (i = 0; s[i]; i++)
@@ -676,6 +689,9 @@ struct tcb *tcp;
 #endif
 #ifdef __NR_exit_group
 	case __NR_exit_group:
+#endif
+#ifdef IA64
+	case 252: /* IA-32 __NR_exit_group */
 #endif
 		internal_exit(tcp);
 		break;
@@ -713,7 +729,7 @@ struct tcb *tcp;
 	static long r28;
 #elif defined(SH)
        static long r0;
-#elif defined(SHMEDIA)
+#elif defined(SH64)
        static long r9;
 #elif defined(X86_64)
        static long rax;
@@ -734,14 +750,6 @@ struct tcb *tcp;
 
 #ifdef LINUX
 #if defined(S390) || defined(S390X)
-	if (upeek(pid, PT_GPR2, &syscall_mode) < 0)
-		return -1;
-	if (syscall_mode != -ENOSYS) {
-		/*
-		 * Since kernel version 2.5.44 the scno gets passed in gpr2.
-		 */
-		scno = syscall_mode;
-	}
 	if (tcp->flags & TCB_WAITEXECVE) {
 		/*
 		 * When the execve system call completes successfully, the
@@ -761,7 +769,16 @@ struct tcb *tcp;
 		tcp->flags &= ~TCB_WAITEXECVE;
 		return 0;
 	}
-	else {
+
+	if (upeek(pid, PT_GPR2, &syscall_mode) < 0)
+			return -1;
+
+	if (syscall_mode != -ENOSYS) {
+		/*
+ 		 * Since kernel version 2.5.44 the scno gets passed in gpr2.
+		 */
+		scno = syscall_mode;
+	} else {
 	       	/*
 		 * Old style of "passing" the scno via the SVC instruction.
 		 */
@@ -1143,7 +1160,7 @@ struct tcb *tcp;
                        return 0;
                }
        }
-#elif defined(SHMEDIA)
+#elif defined(SH64)
 	if (upeek(pid, REG_SYSCALL, &scno) < 0)
 		return -1;
         scno &= 0xFFFF;
@@ -1155,7 +1172,7 @@ struct tcb *tcp;
 			return 0;
 		}
 	}
-#endif /* SHMEDIA */
+#endif /* SH64 */
 #endif /* LINUX */
 #ifdef SUNOS4
 	if (upeek(pid, uoff(u_arg[7]), &scno) < 0)
@@ -1164,7 +1181,7 @@ struct tcb *tcp;
         /* new syscall ABI returns result in R0 */
         if (upeek(pid, 4*REG_REG0, (long *)&r0) < 0)
                 return -1;
-#elif defined(SHMEDIA)
+#elif defined(SH64)
         /* ABI defines result returned in r9 */
         if (upeek(pid, REG_GENERAL(9), (long *)&r9) < 0)
                 return -1;
@@ -1410,7 +1427,7 @@ struct tcb *tcp;
 		}
 #else
 #ifdef POWERPC
-		if (result && (unsigned) -result < nerrnos) {
+		if (result && (unsigned long) -result < nerrnos) {
 			tcp->u_rval = -1;
 			u_error = -result;
 		}
@@ -1480,7 +1497,7 @@ struct tcb *tcp;
                        u_error = 0;
                }
 #else
-#ifdef SHMEDIA
+#ifdef SH64
                 /* interpret result as return value or error number */
                 if (r9 && (unsigned) -r9 < nerrnos) {
 	                tcp->u_rval = -1;
@@ -1490,7 +1507,7 @@ struct tcb *tcp;
                         tcp->u_rval = r9;
 	                u_error = 0;
                 }
-#endif /* SHMEDIA */
+#endif /* SH64 */
 #endif /* SH */
 #endif /* HPPA */
 #endif /* SPARC */
@@ -1588,8 +1605,6 @@ force_result(tcp, error, rval)
 #ifdef LINUX
 #if defined(S390) || defined(S390X)
 	gpr2 = error ? -error : rval;
-	if (upeek(tcp->pid, PT_GPR2, &gpr2) < 0)
-		return -1;
 	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)PT_GPR2, gpr2) < 0)
 		return -1;
 #else /* !S390 && !S390X */
@@ -1657,8 +1672,8 @@ force_result(tcp, error, rval)
 		return -1;
 #else /* !M68K */
 #ifdef ARM
-	r0 = error ? -error : rval;
-	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(4*0), r0) < 0)
+       regs.ARM_r0 = error ? -error : rval;
+       if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(4*0), regs.ARM_r0) < 0)
 		return -1;
 #else /* !ARM */
 #ifdef ALPHA
@@ -1698,11 +1713,11 @@ force_result(tcp, error, rval)
 	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(4*REG_REG0), r0) < 0)
 		return -1;
 #else
-#ifdef SHMEDIA
+#ifdef SH64
         r9 = error ? -error : rval;
 	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)REG_GENERAL(9), r9) < 0)
 		return -1;
-#endif /* SHMEDIA */
+#endif /* SH64 */
 #endif /* SH */
 #endif /* HPPA */
 #endif /* SPARC */
@@ -1933,7 +1948,7 @@ struct tcb *tcp;
                                return -1;
                }
         }
-#elif defined(SHMEDIA)
+#elif defined(SH64)
 	{
 		int i;
                 /* Registers used by SH5 Linux system calls for parameters */
@@ -2131,8 +2146,16 @@ struct tcb *tcp;
 			tv_sub(&tv, &tv, &tcp->etime);
 #ifdef LINUX
 			if (tv_cmp(&tv, &tcp->dtime) > 0) {
-				static struct timeval one_tick =
-					{ 0, 1000000 / HZ };
+				static struct timeval one_tick;
+				if (one_tick.tv_usec == 0) {
+					/* Initialize it.  */
+					struct itimerval it;
+					memset(&it, 0, sizeof it);
+					it.it_interval.tv_usec = 1;
+					setitimer(ITIMER_REAL, &it, NULL);
+					getitimer(ITIMER_REAL, &it);
+					one_tick = it.it_interval;
+				}
 
 				if (tv_nz(&tcp->dtime))
 					tv = tcp->dtime;
@@ -2182,6 +2205,9 @@ struct tcb *tcp;
 			case ERESTARTNOHAND:
 				tprintf("= ? ERESTARTNOHAND (To be restarted)");
 				break;
+			case ERESTART_RESTARTBLOCK:
+				tprintf("= ? ERESTART_RESTARTBLOCK (To be restarted)");
+				break;
 #endif /* LINUX */
 			default:
 				tprintf("= -1 ");
@@ -2416,6 +2442,9 @@ struct tcb *tcp;
 	if (upeek(tcp->pid, 4*(REG_REG0+1), &val) < 0)
 		return -1;
 #endif /* SPARC */
+#elif defined(IA64)
+	if (upeek(tcp->pid, PT_R9, &val) < 0)
+		return -1;
 #endif /* LINUX */
 
 #ifdef SUNOS4
