@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.43 2003/06/03 23:28:59 roland Exp $
+ *	$Id: util.c,v 1.50 2004/03/02 08:50:42 roland Exp $
  */
 
 #include "defs.h"
@@ -63,7 +63,15 @@
 # define PTRACE_PEEKUSR PTRACE_PEEKUSER
 #elif defined(HAVE_LINUX_PTRACE_H)
 #undef PTRACE_SYSCALL
+# ifdef HAVE_STRUCT_IA64_FPREG
+#  define ia64_fpreg XXX_ia64_fpreg
+# endif
+# ifdef HAVE_STRUCT_PT_ALL_USER_REGS
+#  define pt_all_user_regs XXX_pt_all_user_regs
+# endif
 #include <linux/ptrace.h>
+# undef ia64_fpreg
+# undef pt_all_user_regs
 #endif
 
 #ifdef SUNOS4_KERNEL_ARCH_KLUDGE
@@ -313,6 +321,15 @@ char *fmt;
 	tprintf("]");
 }
 
+void
+printuid(text, uid)
+const char *text;
+unsigned long uid;
+{
+	tprintf("%s", text);
+	tprintf((uid == -1) ? "%ld" : "%lu", uid);
+}
+
 static char path[MAXPATHLEN + 1];
 
 void
@@ -974,7 +991,7 @@ struct tcb *tcp;
 #elif defined(SH)
        if (upeek(tcp->pid, 4*REG_PC ,&pc) < 0)
                return -1;
-#elif defined(SHMEDIA)
+#elif defined(SH64)
        if (upeek(tcp->pid, REG_PC ,&pc) < 0)
                return -1;
 #endif
@@ -1092,7 +1109,7 @@ struct tcb *tcp;
                return;
        }
        tprintf("[%08lx] ", pc);
-#elif defined(SHMEDIA)
+#elif defined(SH64)
 	long pc;
 
 	if (upeek(tcp->pid, REG_PC, &pc) < 0) {
@@ -1145,6 +1162,11 @@ struct tcb *tcp;
 
 #ifdef IA64
 
+/* We don't have fork()/vfork() syscalls on ia64 itself, but the ia32
+   subsystem has them for x86... */
+#define SYS_fork	2
+#define SYS_vfork	190
+
 typedef unsigned long *arg_setup_state;
 
 static int
@@ -1152,6 +1174,9 @@ arg_setup(struct tcb *tcp, arg_setup_state *state)
 {
 	unsigned long *bsp, cfm, sof, sol;
 
+	if (ia32)
+		return 0;
+
 	if (upeek(tcp->pid, PT_AR_BSP, (long *) &bsp) < 0)
 		return -1;
 	if (upeek(tcp->pid, PT_CFM, (long *) &cfm) < 0)
@@ -1171,35 +1196,61 @@ arg_setup(struct tcb *tcp, arg_setup_state *state)
 static int
 get_arg0 (struct tcb *tcp, arg_setup_state *state, long *valp)
 {
-	return umoven (tcp, (unsigned long) ia64_rse_skip_regs(*state, 0),
-		       sizeof(long), (void *) valp);
+	int ret;
+
+	if (ia32)
+		ret = upeek (tcp->pid, PT_R11, valp);
+	else
+		ret = umoven (tcp,
+			      (unsigned long) ia64_rse_skip_regs(*state, 0),
+			      sizeof(long), (void *) valp);
+	return ret;
 }
 
 static int
 get_arg1 (struct tcb *tcp, arg_setup_state *state, long *valp)
 {
-	return umoven (tcp, (unsigned long) ia64_rse_skip_regs(*state, 1),
-		       sizeof(long), (void *) valp);
+	int ret;
+
+	if (ia32)
+		ret = upeek (tcp->pid, PT_R9, valp);
+	else
+		ret = umoven (tcp,
+			      (unsigned long) ia64_rse_skip_regs(*state, 1),
+			      sizeof(long), (void *) valp);
+	return ret;
 }
 #endif
 
 static int
 set_arg0 (struct tcb *tcp, arg_setup_state *state, long val)
 {
-	unsigned long *ap;
-	ap = ia64_rse_skip_regs(*state, 0);
+	int req = PTRACE_POKEDATA;
+	void *ap;
+
+	if (ia32) {
+		ap = (void *) (intptr_t) PT_R11;	 /* r11 == EBX */
+		req = PTRACE_POKEUSER;
+	} else
+		ap = ia64_rse_skip_regs(*state, 0);
 	errno = 0;
-	ptrace(PTRACE_POKEDATA, tcp->pid, (void *) ap, val);
+	ptrace(req, tcp->pid, ap, val);
 	return errno ? -1 : 0;
 }
 
 static int
 set_arg1 (struct tcb *tcp, arg_setup_state *state, long val)
 {
-	unsigned long *ap;
-	ap = ia64_rse_skip_regs(*state, 1);
+	int req = PTRACE_POKEDATA;
+	void *ap;
+
+	if (ia32) {
+		ap = (void *) (intptr_t) PT_R9;		/* r9 == ECX */
+		req = PTRACE_POKEUSER;
+	} else
+		ap = ia64_rse_skip_regs(*state, 1);
 	errno = 0;
-	ptrace(PTRACE_POKEDATA, tcp->pid, (void *) ap, val);
+	ptrace(req, tcp->pid, ap, val);
 	return errno ? -1 : 0;
 }
 
@@ -1229,6 +1280,8 @@ typedef struct regs arg_setup_state;
 #  define arg1_offset	PT_ORIGGPR2
 #  define restore_arg0(tcp, state, val) ((void) (state), 0)
 #  define restore_arg1(tcp, state, val) ((void) (state), 0)
+#  define arg0_index	1
+#  define arg1_index	0
 # elif defined (ALPHA) || defined (MIPS)
 #  define arg0_offset	REG_A0
 #  define arg1_offset	(REG_A0+1)
@@ -1245,7 +1298,7 @@ typedef struct regs arg_setup_state;
 # elif defined (SH)
 #  define arg0_offset	(4*(REG_REG0+4))
 #  define arg1_offset	(4*(REG_REG0+5))
-# elif defined (SHMEDIA)
+# elif defined (SH64)
    /* ABI defines arg0 & 1 in r2 & r3 */
 #  define arg0_offset   (REG_OFFSET+16)
 #  define arg1_offset   (REG_OFFSET+24)
@@ -1288,6 +1341,11 @@ set_arg1 (struct tcb *tcp, void *cookie, long val)
 # define restore_arg1(tcp, state, val) set_arg1((tcp), (state), (val))
 #endif
 
+#ifndef arg0_index
+# define arg0_index 0
+# define arg1_index 1
+#endif
+
 int
 setbpt(tcp)
 struct tcb *tcp;
@@ -1316,8 +1374,8 @@ struct tcb *tcp;
 		    || set_arg1 (tcp, &state, 0) < 0
 		    || arg_finish_change (tcp, &state) < 0)
 			return -1;
-		tcp->u_arg[0] = CLONE_PTRACE|SIGCHLD;
-		tcp->u_arg[1] = 0;
+		tcp->u_arg[arg0_index] = CLONE_PTRACE|SIGCHLD;
+		tcp->u_arg[arg1_index] = 0;
 		tcp->flags |= TCB_BPTSET;
 		return 0;
 #endif
@@ -1326,14 +1384,15 @@ struct tcb *tcp;
 #ifdef SYS_clone2
 	case SYS_clone2:
 #endif
-		if ((tcp->u_arg[0] & CLONE_PTRACE) == 0
+		if ((tcp->u_arg[arg0_index] & CLONE_PTRACE) == 0
 		    && (arg_setup (tcp, &state) < 0
-			|| set_arg0 (tcp, &state, tcp->u_arg[0] | CLONE_PTRACE) < 0
+			|| set_arg0 (tcp, &state,
+				     tcp->u_arg[arg0_index] | CLONE_PTRACE) < 0
 			|| arg_finish_change (tcp, &state) < 0))
 			return -1;
 		tcp->flags |= TCB_BPTSET;
-		tcp->inst[0] = tcp->u_arg[0];
-		tcp->inst[1] = tcp->u_arg[1];
+		tcp->inst[0] = tcp->u_arg[arg0_index];
+		tcp->inst[1] = tcp->u_arg[arg1_index];
 		return 0;
 
 	default:
